==> react-responsive-picture-1.0.6.tgz: package/src/components/Picture.jsx <==
import React from "react";
import PropTypes from "prop-types";
import { css } from "glamor";
import picturefill from "picturefill";

class Picture extends React.PureComponent {
    componentDidMount() {
        picturefill();
    }

    getImageStyles() {
        return css(this.props.style);
    }

    renderSources() {
        const ieVersion = document.documentMode ? document.documentMode : -1;
        const { sources } = this.props;

        if (sources == null) {
            return null;
        }

        const mappedSources = sources.map((source, index) => {
            if (source.srcSet == null) {
                return null;
            }

            return (
                <source
                    key={index}
                    srcSet={source.srcSet}
                    media={source.media}
                    type={source.type}
                />
            );
        });

        // IE9 requires the sources to be wrapped around an <audio> tag.
        if (ieVersion === 9) {
            return (
                <video style={{ display: "none" }}>
                    {mappedSources}
                </video>
            );
        }

        return mappedSources;
    }

    renderImage(skipSizes = false) {
        // Adds sizes props if sources isn't defined
        const sizesProp = skipSizes ? null : { sizes: this.props.sizes };
        return (
            <img
                alt={this.props.alt}
                srcSet={this.props.src}
                className={this.props.className}
                data-no-retina={true}
                {...sizesProp}
                {...this.getImageStyles()}
            />
        );
    }

    render() {
        if (this.props.sources != null) {
            return (
                <picture>
                    {this.renderSources()}
                    {this.renderImage(true)}
                </picture>
            );
        }

        return this.renderImage();
    }
}

Picture.propTypes = {
    sources: PropTypes.array,
    src: PropTypes.string.isRequired,
    style: PropTypes.oneOfType([
        PropTypes.array,
        PropTypes.object,
    ]),
    alt: PropTypes.string,
    className: PropTypes.string,
    sizes: PropTypes.string,
};

Picture.defaultProps = {
    src: "data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==",
};

export default Picture;

==> react-responsive-picture-2.0.0.tgz: package/src/components/Picture.jsx <==
import React from "react";
import PropTypes from "prop-types";
import picturefill from "picturefill";
import glamorous from "glamorous";

const Img = glamorous.img();

class Picture extends React.PureComponent {
    componentDidMount() {
        picturefill();
    }

    renderSources() {
        const ieVersion = document.documentMode ? document.documentMode : -1;
        const { sources } = this.props;

        if (sources == null) {
            return null;
        }

        const mappedSources = sources.map((source, index) => {
            if (source.srcSet == null) {
                return null;
            }

            return (
                <source
                    key={index}
                    srcSet={source.srcSet}
                    media={source.media}
                    type={source.type}
                />
            );
        });

        // IE9 requires the sources to be wrapped around an <audio> tag.
        if (ieVersion === 9) {
            return (
                <video style={{ display: "none" }}>
                    {mappedSources}
                </video>
            );
        }

        return mappedSources;
    }

    renderImage(props, skipSizes = false) {
        const { alt, src, sizes, ...rest } = props;

        // Adds sizes props if sources isn't defined
        const sizesProp = skipSizes ? null : { sizes };

        return (
            <Img
                alt={alt}
                srcSet={src}
                data-no-retina={true}
                {...sizesProp}
                {...rest}
            />
        );
    }

    render() {
        const { sources, ...rest } = this.props;
        if (sources != null) {
            return (
                <picture>
                    {this.renderSources()}
                    {this.renderImage(rest, true)}
                </picture>
            );
        }

        return this.renderImage(rest);
    }
}

Picture.propTypes = {
    sources: PropTypes.array,
    src: PropTypes.string.isRequired,
    style: PropTypes.object,
    css: PropTypes.oneOfType([
        PropTypes.array,
        PropTypes.object,
        PropTypes.string,
    ]),
    alt: PropTypes.string,
    className: PropTypes.string,
    sizes: PropTypes.string,
};

Picture.defaultProps = {
    src: "data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==",
};

export default Picture;
